@@ -4,6 +4,7 @@ Possible destinations: PYPI.
 """
 import subprocess
 import os
+import mylogging
 
 from . import misc
 
@@ -17,6 +18,12 @@ def deploy_to_pypi(setup_path=None):
         username
         password
     """
+    try:
+        os.environ['TWINE_USERNAME']
+        os.environ['TWINE_PASSWORD']
+    except KeyError:
+        raise KeyError(mylogging.return_str('Setup env vars TWINE_USERNAME and TWINE_PASSWORD to use deploy.'))
+
     setup_path = misc.root_path if not setup_path else setup_path
 
     subprocess.run(['python', 'setup.py', 'sdist', 'bdist_wheel'], cwd=misc.root_path, shell=True, check=True)
