@@ -3,6 +3,7 @@ Only internal helping module for other modules. Not supposed to be used by users
 """
 from pathlib import Path
 import sys
+import mylogging
 
 
 # Root is usually current working directory, if not, use `set_root` function.
@@ -54,4 +55,4 @@ def find_path(file, folder=None, exclude=['node_modules', 'build', 'dist'], leve
                 return i
 
     # If not returned - not found
-    raise FileNotFoundError('File not found')
+    raise FileNotFoundError(mylogging.return_str(f'File `{file}` not found'))
