@@ -14,13 +14,18 @@ import numpy as np
 
 import mylogging
 
+from . import misc
+
 with warnings.catch_warnings():
     warnings.filterwarnings('ignore', module='eel', category=ResourceWarning)
 
     import eel
 
 
-def run_gui(multiprocessing=False, log_file_path=None):
+expose_error_callback = None
+
+
+def run_gui(devel=None, is_multiprocessing=False, log_file_path=None, builded_gui_path=None):
     """Function that init and run `eel` project.
     It will autosetup chrome mode (if installed chrome or chromium, open separate window with
     no url bar, no bookmarks etc...) if not chrome installed, it open microsoft Edge (by default on windows).
@@ -29,43 +34,62 @@ def run_gui(multiprocessing=False, log_file_path=None):
     # In devel mode, app is connected on live vue server.
 
     Args:
-        multiprocessing (bool, optional): If using multiprocessing in some library, set up to True. Defaults to False.
+        devel((bool, None), optional): If None, detected. Can be overwritten. Devel 0 run static assets, 1 run Vue server on localhost. Defaults to None.
+        is_multiprocessing (bool, optional): If using multiprocessing in some library, set up to True. Defaults to False.
         log_file_path ((str, Path, None)), optional): If not exist, it will create, if exist, it will append,
-        if None, log to relative log.log and only if in production mode.
+            if None, log to relative log.log and only if in production mode.
+        builded_gui_path ((str, Path, None)), optional): Where the web asset is. Only if debug is 0 but not run with pyinstaller. If None, it's automatically find (but is slower then). Defaults to None.
     """
 
     try:
-        devel = False if os.environ.get('MY_PYTHON_VUE_ENVIRONMENT') == 'production' else True
+        if devel is None:
+            # env var MY_PYTHON_VUE_ENVIRONMENT is configured and added with pyinstaller automatically in build module
+            devel = False if os.environ.get('MY_PYTHON_VUE_ENVIRONMENT') == 'production' else True
+
+        # Whether run is from .exe or from python
+        is_builded = True if getattr(sys, 'frozen', False) else False
 
         if log_file_path:
             log_file = log_file_path
         else:
-            log_file = 'log.log' if not devel else None
+            log_file = 'log.log' if is_builded else None
 
         mylogging.config.TO_FILE = log_file
 
-        if getattr(sys, 'frozen', False):
+        if is_builded:
+            # gui folder is created with pyinstaller in build
             gui_path = Path(sys._MEIPASS) / 'gui'
         else:
-            gui_path = Path(__file__).resolve().parent / 'gui'
+            if devel:
+                gui_path = misc.find_path('index.html', exclude=['node_modules', 'build']).parents[1] / 'src'
+            else:
+                if builded_gui_path:
+                    gui_path = Path(builded_gui_path)
+                else:
+                    gui_path = misc.find_path('index.html', exclude=['public', 'node_modules', 'build']).parent
+
+
+        if not gui_path.exists():
+            raise FileNotFoundError('Web files not found, setup gui_path (where builded index.html is).')
 
         if devel:
-            directory = gui_path / 'src'
+            directory = gui_path
             app = None
             page = {'port': 8080}
             port = 8686
+            init_files = ['.vue', '.js', '.html']
 
             def close_callback(page, sockets):
                 pass
 
         else:
-            directory = gui_path / 'web_builded'
+            directory = gui_path
             close_callback = None
             app = 'chrome'
             page = 'index.html'
             port = 0
 
-        eel.init(directory.as_posix(), ['.vue', '.js', '.html'])
+        eel.init(directory.as_posix(), ['.vue', '.js', '.html'], exlcude_patterns=['chunk-vendors'])
 
         # try:
         # if devel:
@@ -79,14 +103,11 @@ def run_gui(multiprocessing=False, log_file_path=None):
 
         # if not already_run:
 
-        #     subprocess.Popen(f"cd '{pystore.gui_path.as_posix()}' && npm run serve", stdout=subprocess.PIPE,
-        #                      shell=True)
-        #     print("\nVue starting, reload page after loaded! \n")
-        #     import webbrowser
-        #     webbrowser.open('http://localhost:8080/', new=2)
+        eel.init(directory.as_posix(), init_files)
 
-        if multiprocessing:
-            multiprocessing.freeze_support()
+        if is_multiprocessing:
+            from multiprocessing import freeze_support
+            freeze_support()
 
         mylogging.info("Py side started")
 
@@ -95,7 +116,6 @@ def run_gui(multiprocessing=False, log_file_path=None):
     except OSError:
         eel.start(page, mode='edge', host='localhost', close_callback=close_callback, port=port, disable_cache=True),
 
-
     except Exception:
         mylogging.traceback("Py side terminated...")
 
@@ -153,8 +173,14 @@ def help_starter_pack_vue_app():
     ### main.js
     ############
 
-    if (ProcessingInstruction.env.NODE_ENV !== 'production') {
-      window.eel.set_host("ws://localhost:8686")
+    ```js
+    if (process.env.NODE_ENV == 'development') {
+    Vue.config.productionTip = true
+    Vue.config.devtools = true
+    window.eel.set_host("ws://localhost:8686");
+    } else {
+    Vue.config.productionTip = false
+    Vue.config.devtools = false
     }
 
     // You can expose function to be callable from python. Import and then
@@ -174,10 +200,35 @@ def help_starter_pack_vue_app():
 
     In public folder
 
-    ```
+    ```html
     <script type="text/javascript" src="<%= VUE_APP_EEL %>"></script>
     ```
 
+    ###################
+    ### vue.config.js
+    #################
+
+    ```js
+    let devtool_mode
+    if (process.env.NODE_ENV === 'development') {
+    devtool_mode = 'source-map';
+    } else {
+    devtool_mode = false;
+    }
+
+    module.exports = {
+    outputDir: "web_builded",
+    transpileDependencies: [
+        "vuetify"
+    ],
+    productionSourceMap: process.env.NODE_ENV != 'production',
+
+    configureWebpack: {
+        devtool: devtool_mode,
+    }
+    }
+    ```
+
     #################
     ### Tips, trips
     ################
@@ -192,6 +243,19 @@ def help_starter_pack_vue_app():
     print(help_starter_pack_vue_app.__doc__)
 
 
+def expose(f):
+    def inner(*args, **kargs):
+        try:
+            return f(*args, **kargs)
+
+        except Exception:
+            mylogging.traceback(f"Unexpected error in function `{f.__name__}`")
+            if expose_error_callback:
+                expose_error_callback()
+
+    eel._expose(f.__name__, inner)
+
+
 def json_to_py(json):
     """Take json / json from JS side and eval it from strings.
     If string to string, if float to float, if object then to dict.
